@@ -1,4 +1,4 @@
-REMOTE_WS = "wss://main.frontier.rpc.robonomics.network"
+REMOTE_WS = "wss://kusama.rpc.robonomics.network"
 TYPE_REGISTRY = {
     "types": {
         "Record": "Vec<u8>",
@@ -13,4 +13,4 @@ TYPE_REGISTRY = {
             "type_mapping": [["start", "Compact<u64>"], ["end", "Compact<u64>"]],
         },
     }
-}
+}
\ No newline at end of file
